package com.migao.config.authority;



import com.migao.config.constant.SystemConstant;
import com.migao.entity.po.User;
import com.migao.mapper.UserMapper;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.http.HttpMethod;
import org.springframework.stereotype.Component;
import org.springframework.web.servlet.HandlerInterceptor;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

/**
 * @author 认证拦截器
 * description
 * createDate     2019/4/15 14:54
 * updateRemark
 * version        1.0
 */

@Slf4j
@Component
public class AuthenticationInterceptor implements HandlerInterceptor {

    @Resource
    private AuthenticationProperties authenticationProperties;
    @Resource
    private UserMapper userMapper;

    @Override
    public boolean preHandle(HttpServletRequest request, HttpServletResponse response, Object handler) {
        if (request.getMethod().equals(HttpMethod.OPTIONS.name())) {
            response.setStatus(HttpServletResponse.SC_OK);
            return true;
        }
        String token = request.getHeader(authenticationProperties.getHeaderName());
        //判断token是否存在
        if (StringUtils.isBlank(token)) {
            token = request.getParameter(authenticationProperties.getHeaderName());
            if (StringUtils.isBlank(token)) {
                AuthUtils.writeJson(response, "请登录");
                return false;
            }
        }
        String[] split = token.split(SystemConstant.BLANK_STRING);
        if (split.length != 2) {
            AuthUtils.writeJson(response, "请登录");
            return false;
        }
        token = split[1];
        //认证token是否合法
        Long userId = JWTUtil.getUserId(token);
        User user = userMapper.selectById(userId);
        if (user == null) {
            AuthUtils.writeJson(response, "请登录");
            return false;
        }
        LoginUtils.CURRENT_USER.set(user);
        if (!JWTUtil.verify(token)) {
            AuthUtils.writeJson(response, "请登录");
            return false;
        }
        return true;
    }


}
