package com.migao.config.authority;


import com.migao.config.constant.SystemConstant;
import com.migao.config.exception.AuthenticationException;
import com.migao.entity.po.User;
import org.apache.commons.lang3.StringUtils;
import org.springframework.web.context.request.RequestContextHolder;
import org.springframework.web.context.request.ServletRequestAttributes;

import javax.servlet.http.HttpServletRequest;


public class LoginUtils {

    public static final ThreadLocal<User> CURRENT_USER = new ThreadLocal<>();

    public static Long getLoginUserId() {
        ServletRequestAttributes requestAttributes = (ServletRequestAttributes) RequestContextHolder.getRequestAttributes();
        if (requestAttributes == null) {
            throw new AuthenticationException("请登录");
        }
        HttpServletRequest request =
                requestAttributes.getRequest();
        String authentication = request.getHeader("Authorization") == null ? (String) request.getServletContext().getAttribute("Authorization") : request.getHeader("Authorization");
        if (StringUtils.isBlank(authentication)) {
            throw new AuthenticationException("请登录");
        }
        String[] split = authentication.split(SystemConstant.BLANK_STRING);
        if (split.length != 2) {
            throw new AuthenticationException("非法令牌");
        }
        authentication = split[1];
        return JWTUtil.getUserId(authentication);
    }

    public static boolean isLogin() {
        ServletRequestAttributes requestAttributes = (ServletRequestAttributes) RequestContextHolder.getRequestAttributes();
        if (requestAttributes == null) {
            return false;
        }
        HttpServletRequest request =
                requestAttributes.getRequest();
        String authentication = request.getHeader("Authorization") == null ? (String) request.getServletContext().getAttribute("Authorization") : request.getHeader("Authorization");
        if (StringUtils.isBlank(authentication)) {
            return false;
        }
        String[] split = authentication.split(SystemConstant.BLANK_STRING);
        if (split.length != 2) {
            return false;
        }
        authentication = split[1];
        if (StringUtils.isBlank(authentication)) {
            return false;
        }
        return true;
    }


    public static User getUser() {
        User user = CURRENT_USER.get();
        if (user != null) {
            return user;
        } else {
            throw new AuthenticationException("请重新登录");
        }
    }

    public static String getToken() {
        ServletRequestAttributes requestAttributes =
                (ServletRequestAttributes) RequestContextHolder.getRequestAttributes();
        if (requestAttributes == null) {
            throw new AuthenticationException("请登录");
        }
        HttpServletRequest request =
                requestAttributes.getRequest();
        String authentication = request.getHeader("Authorization") == null ? (String) request.getServletContext().getAttribute("Authorization") : request.getHeader("Authorization");
        if (StringUtils.isBlank(authentication)) {
            throw new AuthenticationException("请登录");
        }
        String[] split = authentication.split(SystemConstant.BLANK_STRING);
        if (split.length != 2) {
            throw new AuthenticationException("非法令牌");
        }
        authentication = split[1];
        JWTUtil.getUserId(authentication);
        return authentication;

    }
}
