package com.migao.entity.po;

import com.baomidou.mybatisplus.annotation.*;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.hibernate.annotations.GenericGenerator;

import javax.persistence.*;
import java.io.Serializable;
import java.time.LocalDateTime;

/**
 * @author : lcl
 * @date : 2020/4/15 8:50
 */
@Data
@NoArgsConstructor
@AllArgsConstructor
@Builder
@Entity
@Table(name = "t_user")
@org.hibernate.annotations.Table(appliesTo = "t_user", comment = "用户")
@TableName("t_user")
public class User implements Serializable {

    @Id
    @TableId(type = IdType.ASSIGN_ID)
    @GeneratedValue(generator = "snowFlake")
    @GenericGenerator(name = "snowFlake", strategy = "com.migao.config.jpa.SnowIdentityGenerator")
    @Column(name = "id", columnDefinition = "bigint(20) comment '主键'")
    private Long id;

    @Column(name = "department_id", columnDefinition = "bigint(20) comment '部门id'")
    private Long departmentId;

    @Column(name = "name", columnDefinition = "varchar(255) comment '姓名'")
    private String name;

    @Column(name = "username", columnDefinition = "varchar(255) comment '用户/姓名全拼'")
    private String username;

    @Column(name = "password", columnDefinition = "varchar(255) comment '密码'")
    private String password;

    @Column(name = "phone", columnDefinition = "varchar(255) comment '注册手机号'")
    private String phone;

    @Column(name = "email", columnDefinition = "varchar(255) comment '注册邮箱'")
    private String email;

    @Column(name = "head", columnDefinition = "varchar(255) comment '头像'")
    private String head;

    @Column(name = "salt", columnDefinition = "varchar(255) comment '加密盐'")
    private String salt;

    @TableField(fill = FieldFill.INSERT_UPDATE)
    @Column(name = "deleted", columnDefinition = "tinyint(4) comment '逻辑删除 0未删除 1已删除'")
    private Integer deleted;
    @TableField(fill = FieldFill.UPDATE)
    @Column(name = "update_time", columnDefinition = "timestamp DEFAULT CURRENT_TIMESTAMP comment '修改时间'")
    private LocalDateTime updateTime;
    @TableField(fill = FieldFill.UPDATE)
    @JoinColumn(name = "update_user_id", columnDefinition = "bigint(20) comment '最后修改人'")
    private Long updateUserId;
    @Column(name = "delete_time", columnDefinition = "timestamp DEFAULT CURRENT_TIMESTAMP comment '删除时间'")
    private LocalDateTime deleteTime;
    @JoinColumn(name = "delete_user_id", columnDefinition = "bigint(20) comment '删除人'")
    private Long deleteUserId;
    @TableField(fill = FieldFill.INSERT)
    @Column(name = "create_time", columnDefinition = "timestamp DEFAULT CURRENT_TIMESTAMP comment '创建时间'")
    private LocalDateTime createTime;

    @JoinColumn(name = "create_user_id", columnDefinition = "bigint(20) comment '新增人'")
    private Long createUserId;
}