package com.migao.service.impl;

import cn.hutool.crypto.digest.BCrypt;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.migao.config.authority.AuthenticationProperties;
import com.migao.config.authority.JWTUtil;
import com.migao.config.constant.SystemConstant;
import com.migao.config.properties.SystemProperties;
import com.migao.config.response.ResponseBean;
import com.migao.config.response.ResponseBuilder;
import com.migao.entity.po.User;
import com.migao.entity.vo.req.UserInsertReq;
import com.migao.entity.vo.req.UserLoginReq;
import com.migao.entity.vo.res.UserLoginRes;
import com.migao.mapper.UserMapper;
import com.migao.service.UserService;
import com.migao.util.EntityUtils;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;

@Slf4j
@Service
@Transactional(rollbackFor = {Exception.class})
public class UserServiceImpl implements UserService {

    @Resource
    private AuthenticationProperties authenticationProperties;

    @Resource
    private UserMapper userMapper;
    @Resource
    private SystemProperties systemProperties;

    @Override
    public ResponseEntity<?> login(UserLoginReq userLoginReq) {
        LambdaQueryWrapper<User> wrapper = Wrappers.<User>lambdaQuery().eq(User::getUsername, userLoginReq.getUsername());
        User user = userMapper.selectOne(wrapper);
        if (user == null) {
            return ResponseEntity.ok().body(ResponseBuilder.fail("用户名或密码错误"));
        }
        UserLoginRes userLoginRes=new UserLoginRes();
        //校验
        boolean checkPassword = BCrypt.checkpw(userLoginReq.getPassword(), user.getPassword());
        if (!checkPassword) {
            return ResponseEntity.ok().body(ResponseBuilder.fail("用户名或密码错误"));
        }
        String sign = JWTUtil.sign(user.getId());
        sign = StringUtils.join(authenticationProperties.getTokenPrefix(), SystemConstant.BLANK_STRING, sign);
        userLoginRes.setToken(sign);
        if (StringUtils.isBlank(user.getHead())) {
            user.setHead("head.jpg");
        }
        userLoginRes.setHead(systemProperties.getDownloadPrefix() + user.getHead());
        return ResponseEntity.ok().header(authenticationProperties.getHeaderName(), sign).body(ResponseBuilder.ok(userLoginRes));

    }

    @Override
    public ResponseBean<?> insert(UserInsertReq userInsertReq) {
//        if (!userInsertReq.getUsername().matches("[\\u4E00-\\u9FA5]+")) {
//            return ResponseBuilder.fail("用户名必须为中文");
//        }
        LambdaQueryWrapper<User> wrapper = Wrappers.<User>lambdaQuery().eq(User::getUsername, userInsertReq.getUsername());
        User usr = userMapper.selectOne(wrapper);
        if (usr != null) {
            return ResponseBuilder.fail("该用户已存在");
        }
        User user = EntityUtils.copyProperties(userInsertReq, User.class);
        String salt = BCrypt.gensalt();
        user.setSalt(salt);
        user.setPassword(BCrypt.hashpw(user.getPassword(), salt));
        user.setHead("head.jpg");
        user.setName(userInsertReq.getUsername());
//        //设置账号为姓名全拼
//        String pinYin = PinyinUtil.getPinYin(userInsertReq.getUsername());
//        user.setUsername(pinYin);
        userMapper.insert(user);
        return ResponseBuilder.ok();
    }
}
